@@ -33,8 +33,8 @@ class PerformanceTestCase(TestCase):
         pool connection creation time differences
      """
 
-    conncount = 32 # Apache2 default is 2 processes with 64 threads = 128
-    querycount = 30  # multiply by five for number of queries
+    conncount = 64 # Apache2 default is 2 processes with 64 threads = 128
+    querycount = 60  # multiply by five for number of queries
     conns = {'oracle':[],
              'oraclepool':[]}
     rows = {'oracle':0,
@@ -44,10 +44,7 @@ class PerformanceTestCase(TestCase):
     time = {}
     
     def resetTimer(self):
-        self.start = {'oracle':[],
-                      'oraclepool':[]}
-        self.end = {'oracle':[],
-                    'oraclepool':[]}
+        self.start = datetime.now()        
         self.time = {'oracle':0,
                      'oraclepool':0}
         
@@ -75,7 +72,6 @@ class PerformanceTestCase(TestCase):
             print "-----------------------------------------------\n"
             
             for engine in ['oracle','oraclepool']:
-                self.engine = engine
                 DATABASES['default'] = DATABASES[engine]
                 self.addData(engine)
                 self.queryData(engine)
@@ -97,7 +93,7 @@ class PerformanceTestCase(TestCase):
             print 'Oraclepool is %d percent %s Oracle engine' % (speed,adj)
 
     def addData(self, engine):
-        self.dummy_request_start()
+        self.dummy_request_start(engine)
         OneTable(b='here').save()
         OneTable(b='is').save()
         OneTable(b='some').save()
@@ -113,20 +109,20 @@ class PerformanceTestCase(TestCase):
     def queryData(self, engine):
         """ Do a lot of queries """
         for i in range(0, self.querycount):
-            self.dummy_request_start()
-            self.runQuery(b__startswith='f')
-            self.runQuery(b__endswith='h')
-            self.runQuery(b__contains='e')        
-            self.runQuery(twotable__b__startswith='B')
-            self.runQuery(twotable__b__exact='B1')        
+            self.dummy_request_start(engine)
+            self.runQuery(engine, b__startswith='f')
+            self.runQuery(engine, b__endswith='h')
+            self.runQuery(engine, b__contains='e')        
+            self.runQuery(engine, twotable__b__startswith='B')
+            self.runQuery(engine, twotable__b__exact='B1')        
             self.dummy_request_end(engine)
 
-    def runQuery(self, **kwargs):
+    def runQuery(self, engine, **kwargs):
         """ Switch engine each time """
         Q = OneTable.objects.filter(**kwargs)
         for rec in Q:
             retrieve = rec
-            self.rows[self.engine] += 1
+            self.rows[engine] += 1
         return
 
     def setup_conns(self):
@@ -143,7 +139,7 @@ class PerformanceTestCase(TestCase):
             for i in range(0, self.conncount):
                 self.conns[engine].append(None)
 
-    def get_connection(self):
+    def get_connection(self, engine):
         """ The global connection object is switched whenever 
             a different process or threads serves the request
             NB: Must call cursor for it to actually connect to oracle
@@ -152,19 +148,19 @@ class PerformanceTestCase(TestCase):
         if self.newconns:
             globals()['connection'].close()
             globals()['connection'] = None
-            DATABASES['default'] = DATABASES[self.engine]
-            backend = load_backend(self.engine)
+            DATABASES['default'] = DATABASES[engine]
+            backend = load_backend(engine)
             process = randint(0,self.conncount - 1)
-            if not self.conns[self.engine][process]:
-                self.conns[self.engine][process] = backend.DatabaseWrapper(get_settings_dict(self.engine)) 
-                cursor = self.conns[self.engine][process].cursor()
-            globals()['connection'] = self.conns[self.engine][process]
+            if not self.conns[engine][process]:
+                self.conns[engine][process] = backend.DatabaseWrapper(get_settings_dict(engine)) 
+                cursor = self.conns[engine][process].cursor()
+            globals()['connection'] = self.conns[engine][process]
         return
 
-    def dummy_request_start(self):
+    def dummy_request_start(self, engine):
         """ Send the normal signals and start the timer """
         self.start = datetime.now()
-        self.get_connection()
+        self.get_connection(engine)
         globals()['connection'].queries = []        
         signals.request_started.send(sender=self.__class__)
 
@@ -173,6 +169,5 @@ class PerformanceTestCase(TestCase):
         signals.request_finished.disconnect(close_connection)
         signals.request_finished.send(sender=self.__class__)
         signals.request_finished.connect(close_connection)
-        self.end[self.engine].append(datetime.now())
         delta = datetime.now() - self.start
         self.time[engine] += delta.microseconds
